@@ -20,15 +20,14 @@ def main(args, return_df=False, return_wfsim_instructions=False, strax=False):
         tnow = starttime
 
     # Loading data:
-    
     epix_file_loader = epix.file_loader(args['path'],
                                         args['file_name'],
                                         args['debug'],
                                         outer_cylinder=args['outer_cylinder'],
                                         kwargs={'entry_start': args['entry_start'],
                                                 'entry_stop': args['entry_stop']},
-                                        cut_by_eventid=args['cut_by_eventid'],
-                                        cut_nr_only=args['nr_only'],
+                                        cut_by_eventid=args.get('cut_by_eventid', False),
+                                        cut_nr_only=args.get('nr_only', False),
                                         )
     inter, n_simulated_events = epix_file_loader.load_file()
 
@@ -51,6 +50,11 @@ def main(args, return_df=False, return_wfsim_instructions=False, strax=False):
     # Add eventid again:
     result['evtid'] = ak.broadcast_arrays(inter['evtid'][:, 0], result['ed'])[0]
 
+    # Add x_pri, y_pri, z_pri again:
+    result['x_pri'] = ak.broadcast_arrays(inter['x_pri'][:, 0], result['ed'])[0]
+    result['y_pri'] = ak.broadcast_arrays(inter['y_pri'][:, 0], result['ed'])[0]
+    result['z_pri'] = ak.broadcast_arrays(inter['z_pri'][:, 0], result['ed'])[0]
+
     # Sort detector volumes and keep interactions in selected ones:
     if args['debug']:
         print('Removing clusters not in volumes:', *[v.name for v in args['detector_config']])
